@@ -10,6 +10,8 @@ import pymysql
 import logging
 import time
 
+from pymysql.constants.ER import NO
+
 
 class dbmysql:
     def __init__(self, host: str, port: int, user: str, password: str, database: str):
@@ -158,12 +160,35 @@ class dbmysql:
             charset='utf8'
         )
         self.flush_tables_cache()
-
+    
     def commit(self):
-        self.conn.ping()
-        self.conn.commit()
+        self.__execute_err_reconnect(self.__commit)
+
+    def __commit(self):
+        try:
+            self.conn.commit()
+        except:
+            raise(Exception(1))
+
+    def __execute_err_reconnect(self, fn, *args):
+        try:
+            ret = fn(*args)
+        except Exception as e:
+            if str(e) == '1':
+                try:
+                    self.conn.ping()
+                except Exception:
+                    logging.error(f"ping mysql error")
+                    return None
+                ret = fn(*args)
+            else:
+                return None
+        return ret
 
     def get(self, sql: str, params: any = {}) -> tuple:
+        return self.__execute_err_reconnect(self.__get, sql, params)
+
+    def __get(self, sql: str, params: any = {}) -> tuple:
         """
         从数据库获取数据
             @sql:要执行的sql语句，%(key)s 或 %s 表示占位符
@@ -178,7 +203,6 @@ class dbmysql:
             params = (123)
         """
         try:
-            self.conn.ping()
             cursor: pymysql.cursors.Cursor = self.conn.cursor(
                 cursor=pymysql.cursors.SSDictCursor)
             ret = cursor.execute(sql, params)
@@ -194,6 +218,7 @@ class dbmysql:
         except Exception as e:
             logging.error(f"db get error {e.with_traceback(None)}")
             logging.error(f"get sql error:{sql},params = {str(params)}")
+            raise(Exception(1))
 
     def select(self, table: str, cols: list, where: dict, order_by: str = "",  limit: int = None, offset: int = None, order_direction: str = "asc", inject: str = ""):
         """
@@ -236,7 +261,11 @@ class dbmysql:
 
         return self.get(sql, args)
 
-    def post(self, sql: str, params: any = {}) -> bool:
+    def post(self, sql: str, params: any = {}) -> tuple:
+        return self.__execute_err_reconnect(self.__post, sql, params)
+
+
+    def __post(self, sql: str, params: any = {}) -> bool:
         """
         修改数据库数据
             @sql:字符串:要执行的sql语句，%(key)s 或 %s 表示占位符
@@ -250,20 +279,20 @@ class dbmysql:
             params = [123, 'hahaha']
         """
         try:
-            self.conn.ping()
             cursor: pymysql.cursors.Cursor = self.conn.cursor()
             cursor.execute(sql, params)
             cursor.close()
             self.need_commit = True
         except Exception as e:
-            self.conn.rollback()
-            cursor.close()
             logging.error(e.with_traceback(None))
-            logging.error(f"post sql error:{sql},params = {str(params)}")
-            return False
+            logging.error(f"post sql error:{sql}, params = {str(params)}")
+            raise(Exception(1))
         return True
-
+    
     def exec_proc(self, name: str, args: tuple = (), ret_count: tuple = ()) -> tuple:
+        return self.__execute_err_reconnect(self.__exec_proc, name, args, ret_count)
+
+    def __exec_proc(self, name: str, args: tuple = (), ret_count: tuple = ()) -> tuple:
         """
         执行存储过程
             @name:str: 存储过程名None
@@ -280,7 +309,6 @@ class dbmysql:
             结果为folderid = (60,)
         """
         try:
-            self.conn.ping()
             cursor: pymysql.cursors.Cursor = self.conn.cursor()
             cursor.callproc(name, args)
             params = ",".join(f"@_{name}_{i}" for i in ret_count)
@@ -293,6 +321,7 @@ class dbmysql:
         except Exception as e:
             logging.error(e.with_traceback(None))
             logging.error(f"excute procedure error:{name},args = {str(args)}")
+            raise(Exception(1))
 
     def update(self, table: str, values: dict, where: dict, values_func: dict = None, inject: str = ""):
         """
