@@ -117,26 +117,34 @@ class http_server:
 
         @method: str : (get|post|put|delete|option)\n
         @path: str : "/a" "/{prefix}/a" "/a/b/c"\n
+        @option_headers: (True | http header:dict) 会自动添加一个option方法的回调。
+            如果option_header=True 会自动添加 default_cos_header 函数返回的默认跨站 option 方法。
+            如果option_header={"header":value},会将dict中的header作为 option 方法返回的header\n
 
         例如：
         ```
         server = http_server(host,port)
+
+        #1 添加 /test 路径
         @server.route("get", "/test")
         async def test_route(req)
             pass
-
+        #2 添加 /任意值/test 路径，对于nginx反向代理很有用
         @server.route("get", "/{prefix}/test")
         async def test_route(req)
             pass
-
+        
+        #3 添加 默认的跨站option方法
         @server.route("get", "/{prefix}/test", server.default_cos_header())
         async def test_route(req)
             pass
 
+        #4 添加 默认的跨站option方法
         @server.route("get", "/{prefix}/test", True)
         async def test_route(req)
             pass
         ```
+        例3 和 例4 是等价的
         """
         def f(func):
             oh = option_headers
